@@ -33,12 +33,9 @@ _f_fpoint (x, y)
   _plotter->set_pen_color();
   _plotter->set_fill_color();
   
-  /* recompute xfig's `depth' attribute, and keep track of the drawing
-     priority of the object we're drawing */
-  if (_plotter->fig_last_priority >= POLYLINE_PRIORITY)
+  /* update xfig's `depth' attribute */
     if (_plotter->fig_drawing_depth > 0)
       (_plotter->fig_drawing_depth)--;
-  _plotter->fig_last_priority = POLYLINE_PRIORITY;
 
   sprintf(_plotter->page->point,
 	  "#POLYLINE [OPEN]\n%d %d %d %d %d %d %d %d %d %.3f %d %d %d %d %d %d\n\t%d %d\n",
