@@ -22,8 +22,7 @@ _g_erase ()
       return -1;
     }
 
-  if (_plotter->drawstate->PointsInLine > 0
-      || _plotter->drawstate->arc_stashed)
+  if (_plotter->drawstate->points_in_path > 0)
     _plotter->endpath(); /* flush polyline if any */
 
   _reset_outbuf (_plotter->page); /* discard all objects */
