@@ -30,8 +30,7 @@ _g_filltype (level)
       return -1;
     }
 
-  if (_plotter->drawstate->PointsInLine > 0
-      || _plotter->drawstate->arc_stashed)
+  if (_plotter->drawstate->points_in_path > 0)
     _plotter->endpath(); /* flush polyline if any */
 
   if ((level < 0) || (level > 0xffff))
