@@ -3,9 +3,10 @@
 /* Our choice for width of strokes, in terms of virtual pixels.  According
    to ``Calligraphy for Computers'', the Hershey fonts were designed to be
    drawn by an electron beam the intensity of which fell to 50% at a
-   transverse displacement of one unit.  This number is magic. */
+   transverse displacement of one unit.  This number is magic (just
+   slightly greater than sqrt(2)). */
 
-#define HERSHEY_STROKE_WIDTH 1.175
+#define HERSHEY_STROKE_WIDTH 1.42
 
 /* According to Allen Hershey, 1 em = 32 virtual pixels for his alphabets
    of principal size.  But taking into account the width of the strokes
