@@ -1,11 +1,9 @@
 /* This file contains the endpath() method, which is a GNU extension to
-   libplot.  A polyline object may be constructed incrementally, by
-   repeated invocation of the cont() routine.  (See the comments in
-   g_cont.c.)  The construction may be terminated, and the polyline object
-   finalized, by an explict invocation of endpath().
-
-   If endpath() is invoked when no polyline is under construction, it has
-   no effect. */
+   libplot.  A path object may be constructed incrementally, by repeated
+   invocation of such operations as cont(), arc(), etc.  The construction
+   may be terminated, and the path object finalized, by an explict
+   invocation of endpath().  If endpath() is invoked when no path is under
+   construction, it has no effect. */
 
 #include "sys-defines.h"
 #include "plot.h"
@@ -28,9 +26,9 @@ _m_endpath ()
     {
       if (_plotter->portable_output)
 	fprintf (_plotter->outstream, "%c\n", 
-		 ENDPATH);
+		 (int)O_ENDPATH);
       else
-	putc (ENDPATH, _plotter->outstream);
+	putc ((int)O_ENDPATH, _plotter->outstream);
     }
       
   return 0;
