@@ -25,10 +25,10 @@ _m_line (x0, y0, x1, y1)
     {
       if (_plotter->portable_output)
 	fprintf(_plotter->outstream, "%c %d %d %d %d\n", 
-		LINE, x0, y0, x1, y1);
+		(int)O_LINE, x0, y0, x1, y1);
       else
 	{
-	  putc (LINE, _plotter->outstream);
+	  putc ((int)O_LINE, _plotter->outstream);
 	  _emit_integer (x0);
 	  _emit_integer (y0);
 	  _emit_integer (x1);
@@ -57,10 +57,10 @@ _m_fline (x0, y0, x1, y1)
     {
       if (_plotter->portable_output)
 	fprintf(_plotter->outstream, "%c %g %g %g %g\n", 
-		LINE, x0, y0, x1, y1);
+		(int)O_LINE, x0, y0, x1, y1);
       else
 	{
-	  putc (FLINE, _plotter->outstream);
+	  putc ((int)O_FLINE, _plotter->outstream);
 	  _emit_float (x0);
 	  _emit_float (y0);
 	  _emit_float (x1);
